@@ -1,6 +1,7 @@
 import hashlib
 import os
 import sys
+import types
 from importlib import import_module
 from logging import getLogger
 from typing import Union, List, Any, Callable, Set, Optional, Dict
@@ -361,7 +362,7 @@ class TaskOnKart(luigi.Task):
 
     def _get_module_versions(self) -> str:
         module_versions = []
-        for x in set([x.split('.')[0] for x in sys.modules.keys() if '_' not in x]):
+        for x in set([x.split('.')[0] for x in globals().keys() if isinstance(x, types.ModuleType) and '_' not in x]):
             module = import_module(x)
             if '__version__' in dir(module):
                 if type(module.__version__) == str:
